Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(247)

Unified Diff: runtime/vm/simulator_arm.h

Issue 999983004: simMutex (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/pages.h ('k') | runtime/vm/simulator_arm.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/simulator_arm.h
===================================================================
--- runtime/vm/simulator_arm.h (revision 44732)
+++ runtime/vm/simulator_arm.h (working copy)
@@ -24,6 +24,7 @@
class Mutex;
class RawObject;
class SimulatorSetjmpBuffer;
+class Thread;
typedef struct {
union {
@@ -216,31 +217,30 @@
intptr_t ReadExclusiveW(uword addr, Instr* instr);
intptr_t WriteExclusiveW(uword addr, intptr_t value, Instr* instr);
- // In Dart, there is at most one thread per isolate.
- // We keep track of 16 exclusive access address tags across all isolates.
+ // We keep track of 16 exclusive access address tags across all threads.
// Since we cannot simulate a native context switch, which clears
// the exclusive access state of the local monitor (using the CLREX
// instruction), we associate the isolate requesting exclusive access to the
// address tag. Multiple isolates requesting exclusive access (using the LDREX
// instruction) to the same address will result in multiple address tags being
// created for the same address, one per isolate.
// At any given time, each isolate is associated to at most one address tag.
static Mutex* exclusive_access_lock_;
static const int kNumAddressTags = 16;
static struct AddressTag {
- Isolate* isolate;
+ Thread* thread;
uword addr;
} exclusive_access_state_[kNumAddressTags];
static int next_address_tag_;
// Set access to given address to 'exclusive state' for current isolate.
static void SetExclusiveAccess(uword addr);
// Returns true if the current isolate has exclusive access to given address,
// returns false otherwise. In either case, set access to given address to
- // 'open state' for all isolates.
+ // 'open state' for all threads.
// If given addr is NULL, set access to 'open state' for current
- // isolate (CLREX).
+ // thread (CLREX).
static bool HasExclusiveAccessAndOpen(uword addr);
// Executing is handled based on the instruction type.
« no previous file with comments | « runtime/vm/pages.h ('k') | runtime/vm/simulator_arm.cc » ('j') | no next file with comments »
@@ -216,31 +217,30 @@
// Since we cannot simulate a native context switch, which clears
// the exclusive access state of the local monitor (using the CLREX
- // instruction), we associate the isolate requesting exclusive access to the
- // address tag. Multiple isolates requesting exclusive access (using the LDREX
+ // instruction), we associate the thread requesting exclusive access to the
+ // address tag. Multiple threads requesting exclusive access (using the LDREX
// instruction) to the same address will result in multiple address tags being
@@ -216,31 +217,30 @@
// instruction) to the same address will result in multiple address tags being
- // created for the same address, one per isolate.
- // At any given time, each isolate is associated to at most one address tag.
+ // created for the same address, one per thread.
+ // At any given time, each thread is associated to at most one address tag.
static Mutex* exclusive_access_lock_;
static const int kNumAddressTags = 16;
@@ -216,31 +217,30 @@
} exclusive_access_state_[kNumAddressTags];
static int next_address_tag_;
- // Set access to given address to 'exclusive state' for current isolate.
+ // Set access to given address to 'exclusive state' for current thread.
static void SetExclusiveAccess(uword addr);
@@ -216,31 +217,30 @@
static void SetExclusiveAccess(uword addr);
- // Returns true if the current isolate has exclusive access to given address,
+ // Returns true if the current thread has exclusive access to given address,
// returns false otherwise. In either case, set access to given address to

Powered by Google App Engine
This is Rietveld 408576698